spoon.transports.SpoonTransport'

Package spoon :: Package transports :: Module SpoonTransport' |
[hide private]
[frames] | no frames]

# Module SpoonTransport'

source code

Classes | [hide private]
`` | LinkMessage Link message is the wrapper which will contain messages sent between two directly connected nodes.
`` | SpoonStream SpoonStream implements an object stream.
`` | SpoonTransport The spoon transport base class.
`` | SpoonTransportThread
`` | Thread
`` | TransportException
`` | TransportHub Where all of your transports connect to form your glorious new node.

Functions | [hide private]
`` | Semaphore(*args, **kwargs)

Variables | [hide private]
`` | LMTYPE_NETWORK = `1`
`` | LMTYPE_NETWORK_PROTO = `2`

Function Details | [hide private]

### Semaphore(*args, **kwargs) |
None

Variables Details | [hide private]

    ### LMTYPE_NETWORK None Value:
        1

    ### LMTYPE_NETWORK_PROTO None Value:
        2